@@ -15,7 +15,7 @@ BEGIN {
     }
 }
 use warnings;
-our $VERSION = '0.000017';
+our $VERSION = '0.000018';
 use utf8;
 
 # Class for $PPR::ERROR objects...
@@ -1884,7 +1884,7 @@ sub decomment {
 
 sub _uniq {
     my %seen;
-    return grep {!$seen{$_}} @_;
+    return grep {!$seen{$_}++} @_;
 }
 
 sub _croak {
@@ -1903,7 +1903,7 @@ PPR - Pattern-based Perl Recognizer
 
 =head1 VERSION
 
-This document describes PPR version 0.000017
+This document describes PPR version 0.000018
 
 
 =head1 SYNOPSIS
